How to find process id for error sql and match to ps -aef
Posted in 2005
Topics: Stored Procedures & SPL
Hi,
I have got an sql error on onstat -g sql and I would like to know which
process is giving that error.
I tried onstat -g sql, onstat -u, onstat -x but how do I match something to
give me the process-id on onstat -u
Thanks,
Sunil Thakkar
onstat -g sql (Partial list : only one with error displayed)
Informix Dynamic Server Version 7.31.FD2 -- On-Line -- Up 9 days 22:50:15 --
62464 Kbytes
Sess SQL Current Iso Lock SQL ISAM F.E.
Id Stmt type Database Lvl Mode ERR ERR Vers
1054 - hk78_syn CR Wait 30 -240 -134 9.28
onstat -g sql 1054 :
Informix Dynamic Server Version 7.31.FD2 -- On-Line -- Up 9 days 22:50:57 --
62464 Kbytes
Sess SQL Current Iso Lock SQL ISAM F.E.
Id Stmt type Database Lvl Mode ERR ERR Vers
1054 - hk78_syn CR Wait 30 -240 -134 9.28
Last parsed SQL statement :
Last parsed SQL statement :
DELETE from eqa_entry where finish_time <= ?
onstat -u :
Informix Dynamic Server Version 7.31.FD2 -- On-Line -- Up 9 days 22:52:34 --
62464 Kbytes
Userthreads
address flags sessid user tty wait tout locks
nreads nwrites
10a3953a8 Y--P--- 1054 dbommu - 10ba6f288 0 2
1242 1398
92 active, 128 total, 92 maximum concurrent
onstat -x :
Transactions
address flags userthread locks log begin isolation retrys coordin
ator
10a3b9bb0 A---- 10a3953a8 2 0 COMMIT 0
ps -aef | grep dbommu ( partial list only )
UID PID PPID C STIME TTY TIME CMD
daemon 509 1 0 Mar 04 ? 0:00 /usr/lib/nfs/statd
dbommu 28888 28777 0 23:34:57 ? 0:04 orderActivitySvr orderActivitySvr
0
dbommu 28787 28777 0 23:33:47 ? 0:01 srelay srp_relay 0
dbommu 28887 28777 0 23:34:56 ? 0:02 asmServer asmServer 0
dbommu 28777 1 0 23:33:25 ? 4:02 sm
dbommu 29517 29515 0 08:58:54 pts/10 0:00 -ksh
dbommu 28827 28777 0 23:34:00 ? 0:09 ma_advs_mgr ma_advs_mgr 0
dbommu 29986 29771 1 09:35:40 pts/12 0:00 vi InvCxrSystem.C
dbommu 29698 29696 0 09:07:36 pts/12 0:00 -ksh
dbommu 28809 28777 0 23:33:52 ? 0:08 dsl_mgr dsl_mgr 0
********************************************************************************
*******************
The information in this email is confidential and may be legally privileged.
Access to this email by anyone other than the intended addressee is
unauthorized. If you are not the intended recipient of this message, any
review, disclosure, copying, distribution, retention, or any action taken or
omitted to be taken in reliance on it is prohibited and may be unlawful. If
you are not the intended recipient, please reply to or forward a copy of this
message to the sender and delete the message, any attachments, and any copies
thereof from your system.
********************************************************************************
*******************
Try onstat -g ses <session id>
It would display the PID and the hostname.
Thank you,
Kannan Thirugnanam
-----Original Message-----
From: forum.subscriber@iiug.org [mailto:forum.subscriber@iiug.org] On
Behalf Of Thakkar, Sunil
Sent: Thursday, March 24, 2005 11:54 AM
To: ids@iiug.org
Subject: How to find process id for error sql and match to ps -aef
[4604]
Hi,
I have got an sql error on onstat -g sql and I would like to know which
process is giving that error.
I tried onstat -g sql, onstat -u, onstat -x but how do I match something
to give me the process-id on onstat -u
Thanks,
Sunil Thakkar
onstat -g sql (Partial list : only one with error displayed)
Informix Dynamic Server Version 7.31.FD2 -- On-Line -- Up 9 days
22:50:15 --
62464 Kbytes
Sess SQL Current Iso Lock SQL ISAM F.E.
Id Stmt type Database Lvl Mode ERR ERR Vers
1054 - hk78_syn CR Wait 30 -240 -134 9.28
onstat -g sql 1054 :
Informix Dynamic Server Version 7.31.FD2 -- On-Line -- Up 9 days
22:50:57 --
62464 Kbytes
Sess SQL Current Iso Lock SQL ISAM F.E.
Id Stmt type Database Lvl Mode ERR ERR Vers
1054 - hk78_syn CR Wait 30 -240 -134 9.28
Last parsed SQL statement :
Last parsed SQL statement :
DELETE from eqa_entry where finish_time <= ?
onstat -u :
Informix Dynamic Server Version 7.31.FD2 -- On-Line -- Up 9 days
22:52:34 --
62464 Kbytes
Userthreads
address flags sessid user tty wait
tout locks
nreads nwrites
10a3953a8 Y--P--- 1054 dbommu - 10ba6f288 0
2
1242 1398
92 active, 128 total, 92 maximum concurrent
onstat -x :
Transactions
address flags userthread locks log begin isolation retrys
coordin
ator
10a3b9bb0 A---- 10a3953a8 2 0 COMMIT 0
ps -aef | grep dbommu ( partial list only )
UID PID PPID C STIME TTY TIME CMD
daemon 509 1 0 Mar 04 ? 0:00 /usr/lib/nfs/statd
dbommu 28888 28777 0 23:34:57 ? 0:04 orderActivitySvr
orderActivitySvr
0
dbommu 28787 28777 0 23:33:47 ? 0:01 srelay srp_relay 0
dbommu 28887 28777 0 23:34:56 ? 0:02 asmServer asmServer 0
dbommu 28777 1 0 23:33:25 ? 4:02 sm
dbommu 29517 29515 0 08:58:54 pts/10 0:00 -ksh
dbommu 28827 28777 0 23:34:00 ? 0:09 ma_advs_mgr ma_advs_mgr 0
dbommu 29986 29771 1 09:35:40 pts/12 0:00 vi InvCxrSystem.C
dbommu 29698 29696 0 09:07:36 pts/12 0:00 -ksh
dbommu 28809 28777 0 23:33:52 ? 0:08 dsl_mgr dsl_mgr 0
************************************************************************
***************************
The information in this email is confidential and may be legally
privileged. Access to this email by anyone other than the intended
addressee is unauthorized. If you are not the intended recipient of
this message, any review, disclosure, copying, distribution, retention,
or any action taken or omitted to be taken in reliance on it is
prohibited and may be unlawful. If you are not the intended recipient,
please reply to or forward a copy of this message to the sender and
delete the message, any attachments, and any copies thereof from your
system.
************************************************************************
***************************
Onstat -g
ses will give you the process id.
-----Original Message-----
From: forum.subscriber@iiug.org [mailto:forum.subscriber@iiug.org] On
Behalf Of Thakkar, Sunil
Sent: Thursday, March 24, 2005 10:54 AM
To: ids@iiug.org
Subject: How to find process id for error sql and match to ps -aef
[4604]
Hi,
I have got an sql error on onstat -g sql and I would like to know which
process is giving that error.
I tried onstat -g sql, onstat -u, onstat -x but how do I match something
to give me the process-id on onstat -u
Thanks,
Sunil Thakkar
onstat -g sql (Partial list : only one with error displayed)
Informix Dynamic Server Version 7.31.FD2 -- On-Line -- Up 9 days
22:50:15 --
62464 Kbytes
Sess SQL Current Iso Lock SQL ISAM F.E.
Id Stmt type Database Lvl Mode ERR ERR Vers
1054 - hk78_syn CR Wait 30 -240 -134 9.28
onstat -g sql 1054 :
Informix Dynamic Server Version 7.31.FD2 -- On-Line -- Up 9 days
22:50:57 --
62464 Kbytes
Sess SQL Current Iso Lock SQL ISAM F.E.
Id Stmt type Database Lvl Mode ERR ERR Vers
1054 - hk78_syn CR Wait 30 -240 -134 9.28
Last parsed SQL statement :
Last parsed SQL statement :
DELETE from eqa_entry where finish_time <= ?
onstat -u :
Informix Dynamic Server Version 7.31.FD2 -- On-Line -- Up 9 days
22:52:34 --
62464 Kbytes
Userthreads
address flags sessid user tty wait
tout locks
nreads nwrites
10a3953a8 Y--P--- 1054 dbommu - 10ba6f288 0
2
1242 1398
92 active, 128 total, 92 maximum concurrent
onstat -x :
Transactions
address flags userthread locks log begin isolation retrys
coordin
ator
10a3b9bb0 A---- 10a3953a8 2 0 COMMIT 0
ps -aef | grep dbommu ( partial list only )
UID PID PPID C STIME TTY TIME CMD
daemon 509 1 0 Mar 04 ? 0:00 /usr/lib/nfs/statd
dbommu 28888 28777 0 23:34:57 ? 0:04 orderActivitySvr
orderActivitySvr
0
dbommu 28787 28777 0 23:33:47 ? 0:01 srelay srp_relay 0
dbommu 28887 28777 0 23:34:56 ? 0:02 asmServer asmServer 0
dbommu 28777 1 0 23:33:25 ? 4:02 sm
dbommu 29517 29515 0 08:58:54 pts/10 0:00 -ksh
dbommu 28827 28777 0 23:34:00 ? 0:09 ma_advs_mgr ma_advs_mgr 0
dbommu 29986 29771 1 09:35:40 pts/12 0:00 vi InvCxrSystem.C
dbommu 29698 29696 0 09:07:36 pts/12 0:00 -ksh
dbommu 28809 28777 0 23:33:52 ? 0:08 dsl_mgr dsl_mgr 0
************************************************************************
***************************
The information in this email is confidential and may be legally
privileged. Access to this email by anyone other than the intended
addressee is unauthorized. If you are not the intended recipient of
this message, any review, disclosure, copying, distribution, retention,
or any action taken or omitted to be taken in reliance on it is
prohibited and may be unlawful. If you are not the intended recipient,
please reply to or forward a copy of this message to the sender and
delete the message, any attachments, and any copies thereof from your
system.
************************************************************************
***************************
Great. 3 correct responses within 30 to 45 minutes.
I sent the question at 9:52 and I got the response
from ART KAGEL at 10:30
Thirugnanam, kannan at 10:38
and Link, David A at 11:00
This is the first time I sent a question to the group and I am really
impressed.
Thanks to all of you.
Sunil Thakkar
BearingPoint Inc.
-----Original Message-----
From: forum.subscriber@iiug.org [mailto:forum.subscriber@iiug.org]On
Behalf Of Thakkar, Sunil
Sent: Thursday, March 24, 2005 9:54 AM
To: ids@iiug.org
Subject: How to find process id for error sql and match to ps -aef
[4604]
Hi,
I have got an sql error on onstat -g sql and I would like to know which
process is giving that error.
I tried onstat -g sql, onstat -u, onstat -x but how do I match something to
give me the process-id on onstat -u
Thanks,
Sunil Thakkar
onstat -g sql (Partial list : only one with error displayed)
Informix Dynamic Server Version 7.31.FD2 -- On-Line -- Up 9 days 22:50:15 --
62464 Kbytes
Sess SQL Current Iso Lock SQL ISAM F.E.
Id Stmt type Database Lvl Mode ERR ERR Vers
1054 - hk78_syn CR Wait 30 -240 -134 9.28
onstat -g sql 1054 :
Informix Dynamic Server Version 7.31.FD2 -- On-Line -- Up 9 days 22:50:57 --
62464 Kbytes
Sess SQL Current Iso Lock SQL ISAM F.E.
Id Stmt type Database Lvl Mode ERR ERR Vers
1054 - hk78_syn CR Wait 30 -240 -134 9.28
Last parsed SQL statement :
Last parsed SQL statement :
DELETE from eqa_entry where finish_time <= ?
onstat -u :
Informix Dynamic Server Version 7.31.FD2 -- On-Line -- Up 9 days 22:52:34 --
62464 Kbytes
Userthreads
address flags sessid user tty wait tout locks
nreads nwrites
10a3953a8 Y--P--- 1054 dbommu - 10ba6f288 0 2
1242 1398
92 active, 128 total, 92 maximum concurrent
onstat -x :
Transactions
address flags userthread locks log begin isolation retrys coordin
ator
10a3b9bb0 A---- 10a3953a8 2 0 COMMIT 0
ps -aef | grep dbommu ( partial list only )
UID PID PPID C STIME TTY TIME CMD
daemon 509 1 0 Mar 04 ? 0:00 /usr/lib/nfs/statd
dbommu 28888 28777 0 23:34:57 ? 0:04 orderActivitySvr orderActivitySvr
0
dbommu 28787 28777 0 23:33:47 ? 0:01 srelay srp_relay 0
dbommu 28887 28777 0 23:34:56 ? 0:02 asmServer asmServer 0
dbommu 28777 1 0 23:33:25 ? 4:02 sm
dbommu 29517 29515 0 08:58:54 pts/10 0:00 -ksh
dbommu 28827 28777 0 23:34:00 ? 0:09 ma_advs_mgr ma_advs_mgr 0
dbommu 29986 29771 1 09:35:40 pts/12 0:00 vi InvCxrSystem.C
dbommu 29698 29696 0 09:07:36 pts/12 0:00 -ksh
dbommu 28809 28777 0 23:33:52 ? 0:08 dsl_mgr dsl_mgr 0
********************************************************************************
*******************
The information in this email is confidential and may be legally privileged.
Access to this email by anyone other than the intended addressee is
unauthorized. If you are not the intended recipient of this message, any
review, disclosure, copying, distribution, retention, or any action taken or
omitted to be taken in reliance on it is prohibited and may be unlawful. If
you are not the intended recipient, please reply to or forward a copy of this
message to the sender and delete the message, any attachments, and any copies
thereof from your system.
********************************************************************************
*******************
********************************************************************************
*******************
The information in this email is confidential and may be legally privileged.
Access to this email by anyone other than the intended addressee is
unauthorized. If you are not the intended recipient of this message, any
review, disclosure, copying, distribution, retention, or any action taken or
omitted to be taken in reliance on it is prohibited and may be unlawful. If
you are not the intended recipient, please reply to or forward a copy of this
message to the sender and delete the message, any attachments, and any copies
thereof from your system.
********************************************************************************
*******************
Related threads
- Posting from the Informix-list
- Migrating from IDS 9.40.UC6 to 11.50.UC3
- Ip for a network session
- questions onstat -g